@@ -49,7 +49,7 @@ pub struct NotAvailable {
     pub error: String,
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize, Debug, Clone)]
 pub struct Usage {
     pub usage_code: String,
     pub usage_full: String,
@@ -64,7 +64,7 @@ pub struct JsonNameDetailItem {
 }
 
 #[derive(Deserialize, Debug)]
-pub struct JsonNameDetails(Vec<JsonNameDetailItem>);
+pub struct JsonNameDetails(pub Vec<JsonNameDetailItem>);
 
 #[derive(Deserialize, Debug)]
 pub struct JsonNameList {
